ContentDescriptor class abstract

Constructors

ContentDescriptor({required String schemaType, required String title, required List<TypeDescriptor<LayoutConfiguration<ContentItem>>>? layouts})

Properties

hashCode → int
The hash code for this object.
no setterinherited
layouts → List<TypeDescriptor<LayoutConfiguration<ContentItem>>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaType → String
final
sourceFeature → String?
The feature that this content descriptor was registered by.
no setter
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setSourceFeature(String? featureName) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createDefault({required String schemaType, required String title}) → ContentDescriptorFactory<ContentItem>
A simplified approach to creating a ContentDescriptor that follows the standard conventions. This eliminates the need to create a new <Item>ContentDescriptor.