ContentExtensionBuilder class final

Inheritance
  • Object
  • ExtensionBuilder<ExtensionDescriptor>
  • ContentExtensionBuilder

Constructors

ContentExtensionBuilder()

Properties

extensionType → Type
The runtime Type of the extension.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isDisposed → bool
Whether the extension has been disposed.
no setterinherited
isInitialized → bool
Whether the extension is currently initialized.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceFeature → String?
The name of the feature which this extension belongs to. This is set by the bootstrapping process of Vyuh.
no setterinherited
title → String
The title of the extension.
finalinherited

Methods

captureLazyState(ExtensionDescriptor descriptor) → VoidCallback
Captures converter registries and affected content builders for rollback.
override
contentBuilder(String schemaType) → ContentBuilder<ContentItem>?
contentBuilders() → List<ContentBuilder<ContentItem>>
dispose() → Future<void>
Disposes the extension.
inherited
fromJson<T>(String typeName, Map<String, dynamic> json) → T?
init(List<ExtensionDescriptor> extensions) → Future<void>
Initializes the extension.
inherited
isRegistered<T>(String schemaType) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose() → Future<void>
Protected method for subclasses to implement disposal logic.
override
onInit(List<ExtensionDescriptor> extensions) → Future<void>
Protected method for subclasses to implement initialization logic.
override
register<T>(TypeDescriptor<T> descriptor) → void
registerBuilder(ContentBuilder<ContentItem> builder, {List<ContentDescriptor>? descriptors = const []}) → void
Register a ContentBuilder directly This allows other plugins to register content builders programmatically
registerLazy(ExtensionDescriptor descriptor) → void
Registers extensions from a lazily-loaded feature. Override in subclasses that support incremental registration. By default this is a no-op.
override
setSourceFeature(String featureName) → void
Sets the source feature for this extension builder. This is called by the Vyuh bootstrapping process.
inherited
toString() → String
A string representation of this object.
inherited
typeRegistry() → Map<Type, Map<String, TypeDescriptor>>

Operators

operator ==(Object other) → bool
The equality operator.
inherited