UnknownConditionConfiguration class final

Unknown condition configuration placeholder.

Used when a ConditionConfiguration type cannot be resolved during deserialization.

Inheritance

Constructors

UnknownConditionConfiguration({required String missingSchemaType, required Map<String, dynamic> jsonPayload})

Properties

hashCode → int
The hash code for this object.
no setterinherited
jsonPayload → Map<String, dynamic>
final
missingSchemaType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaType → String
The schema type of this configuration.
finalinherited
title → String?
Optional title for this configuration.
finalinherited

Methods

execute(BuildContext context) → Future<String?>
Evaluates this condition configuration.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

schemaName → const String