UnknownLayoutConfiguration<T extends ContentItem> class final

Unknown layout configuration placeholder.

Used when a LayoutConfiguration type cannot be resolved during deserialization.

Inheritance
  • Object
  • LayoutConfiguration<T>
  • UnknownLayoutConfiguration

Constructors

UnknownLayoutConfiguration({required String missingSchemaType, required Map<String, dynamic> jsonPayload})

Properties

contentType → Type
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
jsonPayload → Map<String, dynamic>
final
missingSchemaType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaType → String
The schema type of the content item.
finalinherited

Methods

build(BuildContext context, T content) → Widget
Builds the layout widget tree for the given content item.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

schemaName → const String