UnknownContentIndicator class

A widget that wraps content items to provide visual feedback when they contain unknown actions, conditions, layouts, or modifiers.

In debug mode, this shows a visual indicator (red border + icon) to help developers identify content items with missing type registrations.

Usage:

return UnknownContentIndicator(
  contentItem: card,
  actions: [card.action, card.secondaryAction, card.tertiaryAction],
  child: CardLayout(card: card),
);
Inheritance

Constructors

UnknownContentIndicator({Key? key, required ContentItem contentItem, required Widget child, List<Action?> actions = const [], List<Condition?> conditions = const [], LayoutConfiguration<ContentItem>? layout, bool showDetailOnTap = true})
const

Properties

actions → List<Action?>
Additional actions to check for unknown configurations.
final
child → Widget
The child widget to wrap with the indicator.
final
conditions → List<Condition?>
Additional conditions to check for unknown configurations.
final
contentItem → ContentItem
The content item being checked for unknown content.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
layout → LayoutConfiguration<ContentItem>?
The layout to check (defaults to contentItem.layout).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showDetailOnTap → bool
Whether to show a detailed overlay on tap (debug mode only).
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited